Dummy class abstract

hardcoded ids can hide gaps in real actual process since the _ids logic is no longer handled by mongodb, some of below could be simplified..

Constructors

Dummy()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

address Address
final
adminPermission UserPermissions
final
articleRetail ArticleRetailPb
final
boutiqueMongo BoutiqueMongo
final
boutiqueMongoNoId BoutiqueMongo
final
boutiquePb BoutiquePb
final
calibre CalibrePb
final
chain Chain
final
chainNoId Chain
final
device Device
final
deviceNoId Device
final
firm Firm
final
firmNoId Firm
Deprecated fields kept for backward compat; use licenseDummy / licenses instead.
final
hardwareInfo HardwareInfo
final
licenseDummy License
Starter license (1 user, lifetime). Use for tests.
final
password String
final
salesPersonPermission UserPermissions
final
salesPersonPermissionNoId UserPermissions
final
userPrivate UserPrivate
final
userPublic UserPublic
final