RightSalesperson class abstract

Constructors

RightSalesperson()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

article ArticleRights
final
boolRights BoolRights
final
boutique BoutiqueRights
final
contact ContactRights
final
ticket TicketRights
final