ClientKeepAliveOptions class

KeepAlive support for gRPC, see https://github.com/grpc/grpc/blob/master/doc/keepalive.md. Options to configure a gRPC client for sending keepalive signals.

Constructors

ClientKeepAliveOptions({Duration? pingInterval, Duration timeout = const Duration(seconds: 20), bool permitWithoutCalls = false})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
permitWithoutCalls → bool
If a connection with no active calls should be kept alive by sending pings.
final
pingInterval → Duration?
How often a ping should be sent to keep the connection alive.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shouldSendPings → bool
no setter
timeout → Duration
How long the connection should wait before shutting down after no response to a ping.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited