GrpcData class

Inheritance

Constructors

GrpcData(List<int> data, {required bool isCompressed})

Properties

data → List<int>
final
hashCode → int
The hash code for this object.
no setterinherited
isCompressed → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited