ServerKeepAliveOptions class

Options to configure a gRPC server for receiving keepalive signals.

Constructors

ServerKeepAliveOptions({Duration minIntervalBetweenPingsWithoutData = const Duration(minutes: 5), int? maxBadPings = 2})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxBadPings → int?
The maximum number of bad pings that the server will tolerate before sending an HTTP2 GOAWAY frame and closing the transport.
final
minIntervalBetweenPingsWithoutData → Duration
The minimum time that is expected between receiving successive pings.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited