generateCodeForPairingDevice method

ResponseFuture<CodeForPairingDevice> generateCodeForPairingDevice(
  1. ChainIdAndboutiqueId request, {
  2. CallOptions? options,
})

/ device enrolment follows a different process than user enrolment / generateCodeForPairingDevice is called by web app, it includes chainId and boutiqueId / A device belongs to a boutique TODO rename this create

Implementation

$grpc.ResponseFuture<$1.CodeForPairingDevice> generateCodeForPairingDevice(
  $7.ChainIdAndboutiqueId request, {
  $grpc.CallOptions? options,
}) {
  return $createUnaryCall(_$generateCodeForPairingDevice, request,
      options: options);
}