isADeviceInChain method
ResponseFuture<IsADeviceInChainResponse>
isADeviceInChain(
- ReadDevicesRequest request, {
- CallOptions? options,
/ scans all firm's devices, disregarding user rights / used both in : / weebi_app signups to REQUIRE that user pushes device data / weebi_app device linking to PREVENT user from pushing data, pulling only will be false by default, which is safer since it avoids corrupting data when linking new device that potentially weebi_app with different data == isOneDevice at least
Implementation
$grpc.ResponseFuture<$1.IsADeviceInChainResponse> isADeviceInChain(
$1.ReadDevicesRequest request, {
$grpc.CallOptions? options,
}) {
return $createUnaryCall(_$isADeviceInChain, request, options: options);
}