License class

/ A license purchase. One purchase can cover multiple users (seats). / Each seat has its own validity period.

Inheritance

Constructors

License({String? licenseId, LicensePlan? licensePlan, String? providerProductId, String? providerPriceId, int? maxUsers, Timestamp? validFrom, Timestamp? validUntil, Iterable<LicenseSeat>? seats, PaymentProvider? paymentProvider, String? referredByFirmId, int? creditAppliedCents, String? legalTermsVersionDate})
factory
License.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
License.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

creditAppliedCents int
/ Amount of referral credit (cents) applied to this purchase. Deducted from buyer's firm.
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setteroverride
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
legalTermsVersionDate String
/ CGV / terms version accepted for this purchase (YYYY-MM-DD).
getter/setter pair
licenseId String
getter/setter pair
licensePlan LicensePlan
getter/setter pair
maxUsers int
getter/setter pair
paymentProvider PaymentProvider
/ Which provider processed this purchase.
getter/setter pair
providerPriceId String
getter/setter pair
providerProductId String
getter/setter pair
referredByFirmId String
/ Firm that referred this purchase (referrer). Set when buyer used referrer's code.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seats List<LicenseSeat>
no setter
unknownFields → UnknownFieldSet
no setterinherited
validFrom Timestamp
getter/setter pair
validUntil Timestamp
/ Omitted = lifetime license
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearCreditAppliedCents() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearLegalTermsVersionDate() → void
clearLicenseId() → void
clearLicensePlan() → void
clearMaxUsers() → void
clearPaymentProvider() → void
clearProviderPriceId() → void
clearProviderProductId() → void
clearReferredByFirmId() → void
clearValidFrom() → void
clearValidUntil() → void
clone() License
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
override
copyWith(void updates(License)) License
Apply updates to a copy of this message.
override
createEmptyInstance() License
Creates an empty instance of the same message type as this.
override
ensureValidFrom() Timestamp
ensureValidUntil() Timestamp
extensionsAreInitialized() bool
inherited
freeze() GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasCreditAppliedCents() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasLegalTermsVersionDate() bool
hasLicenseId() bool
hasLicensePlan() bool
hasMaxUsers() bool
hasPaymentProvider() bool
hasProviderPriceId() bool
hasProviderProductId() bool
hasReferredByFirmId() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasValidFrom() bool
hasValidUntil() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create() License
createRepeated() PbList<License>
getDefault() License