StatsServiceBase class abstract

Inheritance
Annotations
  • @GrpcServiceName.new('weebi.stats.service.StatsService')

Constructors

StatsServiceBase()

Properties

$name String
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
getFinancialChart(ServiceCall call, FinancialChartRequest request) Future<FinancialChartResponse>
getFinancialChart_Pre(ServiceCall call, Future<FinancialChartRequest> request) Future<FinancialChartResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited