TicketServiceClient class

Inheritance
Annotations
  • @GrpcServiceName.new('weebi.ticket.service.TicketService')

Constructors

TicketServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) ResponseFuture<R>
inherited
createMany(TicketsRequest request, {CallOptions? options}) ResponseFuture<StatusResponse>
createOne(TicketRequest request, {CallOptions? options}) ResponseFuture<StatusResponse>
deleteOne(TicketRequest request, {CallOptions? options}) ResponseFuture<StatusResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readAll(ReadAllTicketsRequest request, {CallOptions? options}) ResponseFuture<TicketsResponse>
readOne(FindTicketRequest request, {CallOptions? options}) ResponseFuture<TicketPb>
toString() String
A string representation of this object.
inherited
updateStatusOne(TicketRequest request, {CallOptions? options}) ResponseFuture<StatusResponse>

Operators

operator ==(Object other) bool
The equality operator.
inherited