UserPrivate class

/ this is how users are stored in db / this model should not be exposed / used by clients / because it includes password

Inheritance

Constructors

UserPrivate({String? userId, String? mail, String? firstname, String? lastname, Phone? phone, String? passwordEncrypted, String? firmId, UserPermissions? permissions, Timestamp? lastSignIn, String? lastUpdatedByuserId, Timestamp? lastUpdateTimestampUTC, Timestamp? creationDateUTC, bool? mustChangePassword, bool? emailVerificationSent, String? subscriberId, Map<String, String>? othersAttributes})
factory
UserPrivate.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
UserPrivate.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

creationDateUTC Timestamp
getter/setter pair
emailVerificationSent bool
getter/setter pair
firmId String
getter/setter pair
firstname String
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setteroverride
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
lastname String
getter/setter pair
lastSignIn Timestamp
getter/setter pair
lastUpdatedByuserId String
getter/setter pair
lastUpdateTimestampUTC Timestamp
getter/setter pair
mail String
getter/setter pair
mustChangePassword bool
getter/setter pair
othersAttributes Map<String, String>
no setter
passwordEncrypted String
getter/setter pair
permissions UserPermissions
getter/setter pair
phone Phone
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscriberId String
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
userId String
string userId = 1 json_name = 'userId';
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearCreationDateUTC() → void
clearEmailVerificationSent() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearFirmId() → void
clearFirstname() → void
clearLastname() → void
clearLastSignIn() → void
clearLastUpdatedByuserId() → void
clearLastUpdateTimestampUTC() → void
clearMail() → void
clearMustChangePassword() → void
clearPasswordEncrypted() → void
clearPermissions() → void
clearPhone() → void
clearSubscriberId() → void
clearUserId() → void
clone() UserPrivate
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
override
copyWith(void updates(UserPrivate)) UserPrivate
Apply updates to a copy of this message.
override
createEmptyInstance() UserPrivate
Creates an empty instance of the same message type as this.
override
ensureCreationDateUTC() Timestamp
ensureLastSignIn() Timestamp
ensureLastUpdateTimestampUTC() Timestamp
ensurePermissions() UserPermissions
ensurePhone() Phone
extensionsAreInitialized() bool
inherited
freeze() GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasCreationDateUTC() bool
hasEmailVerificationSent() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasFirmId() bool
hasFirstname() bool
hasLastname() bool
hasLastSignIn() bool
hasLastUpdatedByuserId() bool
hasLastUpdateTimestampUTC() bool
hasMail() bool
hasMustChangePassword() bool
hasPasswordEncrypted() bool
hasPermissions() bool
hasPhone() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasSubscriberId() bool
hasUserId() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited