- Inheritance
-
- Annotations
-
- @GrpcServiceName.new('weebi.billing.service.BillingService')
Properties
-
$name
→ String
-
no setteroverride
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$addMethod(ServiceMethod method)
→ void
-
inherited
-
$lookupMethod(String name)
→ ServiceMethod?
-
inherited
-
$onMetadata(ServiceCall context)
→ void
-
Client metadata handler.
inherited
-
createCheckoutSession(ServiceCall call, CreateCheckoutSessionRequest request)
→ Future<CreateCheckoutSessionResponse>
-
-
createCheckoutSession_Pre(ServiceCall call, Future<CreateCheckoutSessionRequest> request)
→ Future<CreateCheckoutSessionResponse>
-
-
createLicense(ServiceCall call, CreateLicenseRequest request)
→ Future<CreateLicenseResponse>
-
-
createLicense_Pre(ServiceCall call, Future<CreateLicenseRequest> request)
→ Future<CreateLicenseResponse>
-
-
deleteLicense(ServiceCall call, DeleteLicenseRequest request)
→ Future<StatusResponse>
-
-
deleteLicense_Pre(ServiceCall call, Future<DeleteLicenseRequest> request)
→ Future<StatusResponse>
-
-
fulfillFromStripeCheckoutSession(ServiceCall call, FulfillFromStripeCheckoutSessionRequest request)
→ Future<CreateLicenseResponse>
-
-
fulfillFromStripeCheckoutSession_Pre(ServiceCall call, Future<FulfillFromStripeCheckoutSessionRequest> request)
→ Future<CreateLicenseResponse>
-
-
fulfillLicenseFromStripe(ServiceCall call, FulfillLicenseFromStripeRequest request)
→ Future<CreateLicenseResponse>
-
-
fulfillLicenseFromStripe_Pre(ServiceCall call, Future<FulfillLicenseFromStripeRequest> request)
→ Future<CreateLicenseResponse>
-
-
getReferralInfo(ServiceCall call, Empty request)
→ Future<GetReferralInfoResponse>
-
-
getReferralInfo_Pre(ServiceCall call, Future<Empty> request)
→ Future<GetReferralInfoResponse>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
readBillingProducts(ServiceCall call, Empty request)
→ Future<ReadBillingProductsResponse>
-
-
readBillingProducts_Pre(ServiceCall call, Future<Empty> request)
→ Future<ReadBillingProductsResponse>
-
-
readLicenses(ServiceCall call, Empty request)
→ Future<ReadLicensesResponse>
-
-
readLicenses_Pre(ServiceCall call, Future<Empty> request)
→ Future<ReadLicensesResponse>
-
-
requestReferralPayout(ServiceCall call, Empty request)
→ Future<RequestReferralPayoutResponse>
-
-
requestReferralPayout_Pre(ServiceCall call, Future<Empty> request)
→ Future<RequestReferralPayoutResponse>
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
updateLicense(ServiceCall call, UpdateLicenseRequest request)
→ Future<StatusResponse>
-
-
updateLicense_Pre(ServiceCall call, Future<UpdateLicenseRequest> request)
→ Future<StatusResponse>
-
-
updatePaymentCustomerId(ServiceCall call, UpdatePaymentCustomerIdRequest request)
→ Future<StatusResponse>
-
-
updatePaymentCustomerId_Pre(ServiceCall call, Future<UpdatePaymentCustomerIdRequest> request)
→ Future<StatusResponse>
-