BillingServiceClient class
- Inheritance
-
- Annotations
-
- @GrpcServiceName.new('weebi.billing.service.BillingService')
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options})
→ ClientCall<Q, R>
-
inherited
-
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options})
→ ResponseStream<R>
-
inherited
-
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options})
→ ResponseFuture<R>
-
inherited
-
createCheckoutSession(CreateCheckoutSessionRequest request, {CallOptions? options})
→ ResponseFuture<CreateCheckoutSessionResponse>
-
-
createLicense(CreateLicenseRequest request, {CallOptions? options})
→ ResponseFuture<CreateLicenseResponse>
-
-
deleteLicense(DeleteLicenseRequest request, {CallOptions? options})
→ ResponseFuture<StatusResponse>
-
-
fulfillFromStripeCheckoutSession(FulfillFromStripeCheckoutSessionRequest request, {CallOptions? options})
→ ResponseFuture<CreateLicenseResponse>
-
-
fulfillLicenseFromStripe(FulfillLicenseFromStripeRequest request, {CallOptions? options})
→ ResponseFuture<CreateLicenseResponse>
-
-
getReferralInfo(Empty request, {CallOptions? options})
→ ResponseFuture<GetReferralInfoResponse>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
readBillingProducts(Empty request, {CallOptions? options})
→ ResponseFuture<ReadBillingProductsResponse>
-
-
readLicenses(Empty request, {CallOptions? options})
→ ResponseFuture<ReadLicensesResponse>
-
-
requestReferralPayout(Empty request, {CallOptions? options})
→ ResponseFuture<RequestReferralPayoutResponse>
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
updateLicense(UpdateLicenseRequest request, {CallOptions? options})
→ ResponseFuture<StatusResponse>
-
-
updatePaymentCustomerId(UpdatePaymentCustomerIdRequest request, {CallOptions? options})
→ ResponseFuture<StatusResponse>
-