TicketTypePb class
- Inheritance
-
- Object
- ProtobufEnum
- TicketTypePb
- Available extensions
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCost → bool
-
Available on TicketTypePb, provided by the TicketTypePbLogic extension
spend and spendDeferred compute totals from item costs. spendCovered and wage use received.no setter - isFinancial → bool
-
Available on TicketTypePb, provided by the TicketTypePbLogic extension
no setter - isPrice → bool
-
Available on TicketTypePb, provided by the TicketTypePbLogic extension
sell and sellDeferred compute totals from item prices. sellCovered uses received (advance repayment — no item price computation).no setter - name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's name or the value if names are not represented.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → TicketTypePb?
Constants
- inventory → const TicketTypePb
- sell → const TicketTypePb
- sellCovered → const TicketTypePb
- sellDeferred → const TicketTypePb
- spend → const TicketTypePb
- spendCovered → const TicketTypePb
- spendDeferred → const TicketTypePb
- stockIn → const TicketTypePb
- stockOut → const TicketTypePb
- unknown → const TicketTypePb
-
values
→ const List<
TicketTypePb> - wage → const TicketTypePb